Photinia
^^^^^^^^^^^^

Photinia is a package used to build deep learning models.
It is lightweight and designed for scientists who wish to implement models quickly with
high flexibility.

Dependencies
------------

* Python 3
* TensorFlow 1.2.0+
* pymongo 3.4+

Installation
------------

The package can be installed directly from PyPI repository::

    pip3 install photinia

